#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class APIKey :
    def __init__( self):
        self.sid = None
        self.displayName = None
        self.subject = None
        self.domainUid = None
        pass

class __APIKeySerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = APIKey()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        sidValue = value['sid']
        instance.sid = serder.STRING.parse(sidValue)
        displayNameValue = value['displayName']
        instance.displayName = serder.STRING.parse(displayNameValue)
        subjectValue = value['subject']
        instance.subject = serder.STRING.parse(subjectValue)
        domainUidValue = value['domainUid']
        instance.domainUid = serder.STRING.parse(domainUidValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        sidValue = value.sid
        instance["sid"] = serder.STRING.encode(sidValue)
        displayNameValue = value.displayName
        instance["displayName"] = serder.STRING.encode(displayNameValue)
        subjectValue = value.subject
        instance["subject"] = serder.STRING.encode(subjectValue)
        domainUidValue = value.domainUid
        instance["domainUid"] = serder.STRING.encode(domainUidValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Server :
    def __init__( self):
        self.ip = None
        self.fqdn = None
        self.name = None
        self.tags = None
        pass

class __ServerSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = Server()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        ipValue = value['ip']
        instance.ip = serder.STRING.parse(ipValue)
        fqdnValue = value['fqdn']
        instance.fqdn = serder.STRING.parse(fqdnValue)
        nameValue = value['name']
        instance.name = serder.STRING.parse(nameValue)
        tagsValue = value['tags']
        instance.tags = serder.ListSerDer(serder.STRING).parse(tagsValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        ipValue = value.ip
        instance["ip"] = serder.STRING.encode(ipValue)
        fqdnValue = value.fqdn
        instance["fqdn"] = serder.STRING.encode(fqdnValue)
        nameValue = value.name
        instance["name"] = serder.STRING.encode(nameValue)
        tagsValue = value.tags
        instance["tags"] = serder.ListSerDer(serder.STRING).encode(tagsValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCardInfo :
    def __init__( self):
        self.kind = None
        self.mail = None
        self.tel = None
        self.formatedName = None
        self.categories = None
        self.memberCount = None
        self.photo = None
        self.source = None
        pass

class __VCardInfoSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = VCardInfo()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.addressbook.api.VCardKind import VCardKind
        from netbluemind.addressbook.api.VCardKind import __VCardKindSerDer__
        kindValue = value['kind']
        instance.kind = __VCardKindSerDer__().parse(kindValue)
        mailValue = value['mail']
        instance.mail = serder.STRING.parse(mailValue)
        telValue = value['tel']
        instance.tel = serder.STRING.parse(telValue)
        formatedNameValue = value['formatedName']
        instance.formatedName = serder.STRING.parse(formatedNameValue)
        from netbluemind.tag.api.TagRef import TagRef
        from netbluemind.tag.api.TagRef import __TagRefSerDer__
        categoriesValue = value['categories']
        instance.categories = serder.ListSerDer(__TagRefSerDer__()).parse(categoriesValue)
        memberCountValue = value['memberCount']
        instance.memberCount = serder.INT.parse(memberCountValue)
        photoValue = value['photo']
        instance.photo = serder.BOOLEAN.parse(photoValue)
        sourceValue = value['source']
        instance.source = serder.STRING.parse(sourceValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.addressbook.api.VCardKind import VCardKind
        from netbluemind.addressbook.api.VCardKind import __VCardKindSerDer__
        kindValue = value.kind
        instance["kind"] = __VCardKindSerDer__().encode(kindValue)
        mailValue = value.mail
        instance["mail"] = serder.STRING.encode(mailValue)
        telValue = value.tel
        instance["tel"] = serder.STRING.encode(telValue)
        formatedNameValue = value.formatedName
        instance["formatedName"] = serder.STRING.encode(formatedNameValue)
        from netbluemind.tag.api.TagRef import TagRef
        from netbluemind.tag.api.TagRef import __TagRefSerDer__
        categoriesValue = value.categories
        instance["categories"] = serder.ListSerDer(__TagRefSerDer__()).encode(categoriesValue)
        memberCountValue = value.memberCount
        instance["memberCount"] = serder.INT.encode(memberCountValue)
        photoValue = value.photo
        instance["photo"] = serder.BOOLEAN.encode(photoValue)
        sourceValue = value.source
        instance["source"] = serder.STRING.encode(sourceValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.icalendar.api.ICalendarElement import ICalendarElement
from netbluemind.icalendar.api.ICalendarElement import __ICalendarElementSerDer__
class VTodo (ICalendarElement):
    def __init__( self):
        ICalendarElement.__init__(self)
        self.due = None
        self.percent = None
        self.completed = None
        self.uid = None
        pass

class __VTodoSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = VTodo()
        __ICalendarElementSerDer__().parseInternal(value,instance)

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dueValue = value['due']
        instance.due = __BmDateTimeSerDer__().parse(dueValue)
        percentValue = value['percent']
        instance.percent = serder.INT.parse(percentValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        completedValue = value['completed']
        instance.completed = __BmDateTimeSerDer__().parse(completedValue)
        uidValue = value['uid']
        instance.uid = serder.STRING.parse(uidValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):
        __ICalendarElementSerDer__().encodeInternal(value,instance)

        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dueValue = value.due
        instance["due"] = __BmDateTimeSerDer__().encode(dueValue)
        percentValue = value.percent
        instance["percent"] = serder.INT.encode(percentValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        completedValue = value.completed
        instance["completed"] = __BmDateTimeSerDer__().encode(completedValue)
        uidValue = value.uid
        instance["uid"] = serder.STRING.encode(uidValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCardCommunications :
    def __init__( self):
        self.tels = None
        self.emails = None
        self.impps = None
        self.langs = None
        pass

class __VCardCommunicationsSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = VCardCommunications()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.addressbook.api.VCardCommunicationsTel import VCardCommunicationsTel
        from netbluemind.addressbook.api.VCardCommunicationsTel import __VCardCommunicationsTelSerDer__
        telsValue = value['tels']
        instance.tels = serder.ListSerDer(__VCardCommunicationsTelSerDer__()).parse(telsValue)
        from netbluemind.addressbook.api.VCardCommunicationsEmail import VCardCommunicationsEmail
        from netbluemind.addressbook.api.VCardCommunicationsEmail import __VCardCommunicationsEmailSerDer__
        emailsValue = value['emails']
        instance.emails = serder.ListSerDer(__VCardCommunicationsEmailSerDer__()).parse(emailsValue)
        from netbluemind.addressbook.api.VCardCommunicationsImpp import VCardCommunicationsImpp
        from netbluemind.addressbook.api.VCardCommunicationsImpp import __VCardCommunicationsImppSerDer__
        imppsValue = value['impps']
        instance.impps = serder.ListSerDer(__VCardCommunicationsImppSerDer__()).parse(imppsValue)
        from netbluemind.addressbook.api.VCardCommunicationsLang import VCardCommunicationsLang
        from netbluemind.addressbook.api.VCardCommunicationsLang import __VCardCommunicationsLangSerDer__
        langsValue = value['langs']
        instance.langs = serder.ListSerDer(__VCardCommunicationsLangSerDer__()).parse(langsValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.addressbook.api.VCardCommunicationsTel import VCardCommunicationsTel
        from netbluemind.addressbook.api.VCardCommunicationsTel import __VCardCommunicationsTelSerDer__
        telsValue = value.tels
        instance["tels"] = serder.ListSerDer(__VCardCommunicationsTelSerDer__()).encode(telsValue)
        from netbluemind.addressbook.api.VCardCommunicationsEmail import VCardCommunicationsEmail
        from netbluemind.addressbook.api.VCardCommunicationsEmail import __VCardCommunicationsEmailSerDer__
        emailsValue = value.emails
        instance["emails"] = serder.ListSerDer(__VCardCommunicationsEmailSerDer__()).encode(emailsValue)
        from netbluemind.addressbook.api.VCardCommunicationsImpp import VCardCommunicationsImpp
        from netbluemind.addressbook.api.VCardCommunicationsImpp import __VCardCommunicationsImppSerDer__
        imppsValue = value.impps
        instance["impps"] = serder.ListSerDer(__VCardCommunicationsImppSerDer__()).encode(imppsValue)
        from netbluemind.addressbook.api.VCardCommunicationsLang import VCardCommunicationsLang
        from netbluemind.addressbook.api.VCardCommunicationsLang import __VCardCommunicationsLangSerDer__
        langsValue = value.langs
        instance["langs"] = serder.ListSerDer(__VCardCommunicationsLangSerDer__()).encode(langsValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ShardStats :
    def __init__( self):
        self.indexName = None
        self.mailboxes = None
        self.topMailbox = None
        self.docCount = None
        self.state = None
        self.size = None
        pass

class __ShardStatsSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = ShardStats()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        indexNameValue = value['indexName']
        instance.indexName = serder.STRING.parse(indexNameValue)
        mailboxesValue = value['mailboxes']
        instance.mailboxes = serder.SetSerDer(serder.STRING).parse(mailboxesValue)
        from netbluemind.mailbox.api.ShardStatsMailboxStats import ShardStatsMailboxStats
        from netbluemind.mailbox.api.ShardStatsMailboxStats import __ShardStatsMailboxStatsSerDer__
        topMailboxValue = value['topMailbox']
        instance.topMailbox = serder.ListSerDer(__ShardStatsMailboxStatsSerDer__()).parse(topMailboxValue)
        docCountValue = value['docCount']
        instance.docCount = serder.LONG.parse(docCountValue)
        from netbluemind.mailbox.api.ShardStatsState import ShardStatsState
        from netbluemind.mailbox.api.ShardStatsState import __ShardStatsStateSerDer__
        stateValue = value['state']
        instance.state = __ShardStatsStateSerDer__().parse(stateValue)
        sizeValue = value['size']
        instance.size = serder.LONG.parse(sizeValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        indexNameValue = value.indexName
        instance["indexName"] = serder.STRING.encode(indexNameValue)
        mailboxesValue = value.mailboxes
        instance["mailboxes"] = serder.SetSerDer(serder.STRING).encode(mailboxesValue)
        from netbluemind.mailbox.api.ShardStatsMailboxStats import ShardStatsMailboxStats
        from netbluemind.mailbox.api.ShardStatsMailboxStats import __ShardStatsMailboxStatsSerDer__
        topMailboxValue = value.topMailbox
        instance["topMailbox"] = serder.ListSerDer(__ShardStatsMailboxStatsSerDer__()).encode(topMailboxValue)
        docCountValue = value.docCount
        instance["docCount"] = serder.LONG.encode(docCountValue)
        from netbluemind.mailbox.api.ShardStatsState import ShardStatsState
        from netbluemind.mailbox.api.ShardStatsState import __ShardStatsStateSerDer__
        stateValue = value.state
        instance["state"] = __ShardStatsStateSerDer__().encode(stateValue)
        sizeValue = value.size
        instance["size"] = serder.LONG.encode(sizeValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class LoginResponse :
    def __init__( self):
        self.status = None
        self.message = None
        self.authKey = None
        self.latd = None
        self.authUser = None
        pass

class __LoginResponseSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = LoginResponse()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.authentication.api.LoginResponseStatus import LoginResponseStatus
        from netbluemind.authentication.api.LoginResponseStatus import __LoginResponseStatusSerDer__
        statusValue = value['status']
        instance.status = __LoginResponseStatusSerDer__().parse(statusValue)
        messageValue = value['message']
        instance.message = serder.STRING.parse(messageValue)
        authKeyValue = value['authKey']
        instance.authKey = serder.STRING.parse(authKeyValue)
        latdValue = value['latd']
        instance.latd = serder.STRING.parse(latdValue)
        from netbluemind.authentication.api.AuthUser import AuthUser
        from netbluemind.authentication.api.AuthUser import __AuthUserSerDer__
        authUserValue = value['authUser']
        instance.authUser = __AuthUserSerDer__().parse(authUserValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.authentication.api.LoginResponseStatus import LoginResponseStatus
        from netbluemind.authentication.api.LoginResponseStatus import __LoginResponseStatusSerDer__
        statusValue = value.status
        instance["status"] = __LoginResponseStatusSerDer__().encode(statusValue)
        messageValue = value.message
        instance["message"] = serder.STRING.encode(messageValue)
        authKeyValue = value.authKey
        instance["authKey"] = serder.STRING.encode(authKeyValue)
        latdValue = value.latd
        instance["latd"] = serder.STRING.encode(latdValue)
        from netbluemind.authentication.api.AuthUser import AuthUser
        from netbluemind.authentication.api.AuthUser import __AuthUserSerDer__
        authUserValue = value.authUser
        instance["authUser"] = __AuthUserSerDer__().encode(authUserValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class DataProtectGeneration :
    def __init__( self):
        self.id = None
        self.protectionTime = None
        self.blueMind = None
        self.withWarnings = None
        self.withErrors = None
        self.parts = None
        pass

class __DataProtectGenerationSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = DataProtectGeneration()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        idValue = value['id']
        instance.id = serder.INT.parse(idValue)
        protectionTimeValue = value['protectionTime']
        instance.protectionTime = serder.DATE.parse(protectionTimeValue)
        from netbluemind.core.api.VersionInfo import VersionInfo
        from netbluemind.core.api.VersionInfo import __VersionInfoSerDer__
        blueMindValue = value['blueMind']
        instance.blueMind = __VersionInfoSerDer__().parse(blueMindValue)
        withWarningsValue = value['withWarnings']
        instance.withWarnings = serder.BOOLEAN.parse(withWarningsValue)
        withErrorsValue = value['withErrors']
        instance.withErrors = serder.BOOLEAN.parse(withErrorsValue)
        from netbluemind.dataprotect.api.PartGeneration import PartGeneration
        from netbluemind.dataprotect.api.PartGeneration import __PartGenerationSerDer__
        partsValue = value['parts']
        instance.parts = serder.ListSerDer(__PartGenerationSerDer__()).parse(partsValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        idValue = value.id
        instance["id"] = serder.INT.encode(idValue)
        protectionTimeValue = value.protectionTime
        instance["protectionTime"] = serder.DATE.encode(protectionTimeValue)
        from netbluemind.core.api.VersionInfo import VersionInfo
        from netbluemind.core.api.VersionInfo import __VersionInfoSerDer__
        blueMindValue = value.blueMind
        instance["blueMind"] = __VersionInfoSerDer__().encode(blueMindValue)
        withWarningsValue = value.withWarnings
        instance["withWarnings"] = serder.BOOLEAN.encode(withWarningsValue)
        withErrorsValue = value.withErrors
        instance["withErrors"] = serder.BOOLEAN.encode(withErrorsValue)
        from netbluemind.dataprotect.api.PartGeneration import PartGeneration
        from netbluemind.dataprotect.api.PartGeneration import __PartGenerationSerDer__
        partsValue = value.parts
        instance["parts"] = serder.ListSerDer(__PartGenerationSerDer__()).encode(partsValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IDataProtect_VERSION = "4.1.51126"

class IDataProtect(BaseEndpoint):
    def __init__(self, apiKey, url ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/dataprotect'

    def saveAll (self):
        postUri = "/_backup";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDataProtect_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def getContent (self, partGen ):
        postUri = "/_content/{partGen}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{partGen}",partGen);
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDataProtect_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def run (self, restoreDefinition ):
        postUri = "/restore";
        __data__ = None
        __encoded__ = None
        from netbluemind.dataprotect.api.RestoreDefinition import RestoreDefinition
        from netbluemind.dataprotect.api.RestoreDefinition import __RestoreDefinitionSerDer__
        __data__ = __RestoreDefinitionSerDer__().encode(restoreDefinition)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDataProtect_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def getRestoreCapabilitiesByTags (self, tags ):
        postUri = "/restore/_capabilities_by_tags";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(tags)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDataProtect_VERSION}, data = __encoded__);
        from netbluemind.dataprotect.api.RestoreOperation import RestoreOperation
        from netbluemind.dataprotect.api.RestoreOperation import __RestoreOperationSerDer__
        return self.handleResult__(serder.ListSerDer(__RestoreOperationSerDer__()), response)
    def installFromGeneration (self, generationId ):
        postUri = "/_install";
        __data__ = None
        __encoded__ = None
        queryParams = {  'generationId': generationId   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDataProtect_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def forget (self, generationId ):
        postUri = "/generations";
        __data__ = None
        __encoded__ = None
        queryParams = {  'generationId': generationId   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDataProtect_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def getRestoreCapabilities (self):
        postUri = "/restore/_capabilities";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDataProtect_VERSION}, data = __encoded__);
        from netbluemind.dataprotect.api.RestoreOperation import RestoreOperation
        from netbluemind.dataprotect.api.RestoreOperation import __RestoreOperationSerDer__
        return self.handleResult__(serder.ListSerDer(__RestoreOperationSerDer__()), response)
    def getRetentionPolicy (self):
        postUri = "/policy";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDataProtect_VERSION}, data = __encoded__);
        from netbluemind.dataprotect.api.RetentionPolicy import RetentionPolicy
        from netbluemind.dataprotect.api.RetentionPolicy import __RetentionPolicySerDer__
        return self.handleResult__(__RetentionPolicySerDer__(), response)
    def updatePolicy (self, rp ):
        postUri = "/policy";
        __data__ = None
        __encoded__ = None
        from netbluemind.dataprotect.api.RetentionPolicy import RetentionPolicy
        from netbluemind.dataprotect.api.RetentionPolicy import __RetentionPolicySerDer__
        __data__ = __RetentionPolicySerDer__().encode(rp)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDataProtect_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getAvailableGenerations (self):
        postUri = "/generations";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDataProtect_VERSION}, data = __encoded__);
        from netbluemind.dataprotect.api.DataProtectGeneration import DataProtectGeneration
        from netbluemind.dataprotect.api.DataProtectGeneration import __DataProtectGenerationSerDer__
        return self.handleResult__(serder.ListSerDer(__DataProtectGenerationSerDer__()), response)
    def syncWithFilesystem (self):
        postUri = "/_syncfs";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDataProtect_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class SearchQuery :
    def __init__( self):
        self.searchSessionId = None
        self.query = None
        self.recordQuery = None
        self.messageId = None
        self.references = None
        self.headerQuery = None
        self.maxResults = None
        self.offset = None
        self.scope = None
        pass

class __SearchQuerySerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = SearchQuery()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        searchSessionIdValue = value['searchSessionId']
        instance.searchSessionId = serder.STRING.parse(searchSessionIdValue)
        queryValue = value['query']
        instance.query = serder.STRING.parse(queryValue)
        recordQueryValue = value['recordQuery']
        instance.recordQuery = serder.STRING.parse(recordQueryValue)
        messageIdValue = value['messageId']
        instance.messageId = serder.STRING.parse(messageIdValue)
        referencesValue = value['references']
        instance.references = serder.STRING.parse(referencesValue)
        from netbluemind.backend.mail.api.SearchQueryHeaderQuery import SearchQueryHeaderQuery
        from netbluemind.backend.mail.api.SearchQueryHeaderQuery import __SearchQueryHeaderQuerySerDer__
        headerQueryValue = value['headerQuery']
        instance.headerQuery = __SearchQueryHeaderQuerySerDer__().parse(headerQueryValue)
        maxResultsValue = value['maxResults']
        instance.maxResults = serder.LONG.parse(maxResultsValue)
        offsetValue = value['offset']
        instance.offset = serder.LONG.parse(offsetValue)
        from netbluemind.backend.mail.api.SearchQuerySearchScope import SearchQuerySearchScope
        from netbluemind.backend.mail.api.SearchQuerySearchScope import __SearchQuerySearchScopeSerDer__
        scopeValue = value['scope']
        instance.scope = __SearchQuerySearchScopeSerDer__().parse(scopeValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        searchSessionIdValue = value.searchSessionId
        instance["searchSessionId"] = serder.STRING.encode(searchSessionIdValue)
        queryValue = value.query
        instance["query"] = serder.STRING.encode(queryValue)
        recordQueryValue = value.recordQuery
        instance["recordQuery"] = serder.STRING.encode(recordQueryValue)
        messageIdValue = value.messageId
        instance["messageId"] = serder.STRING.encode(messageIdValue)
        referencesValue = value.references
        instance["references"] = serder.STRING.encode(referencesValue)
        from netbluemind.backend.mail.api.SearchQueryHeaderQuery import SearchQueryHeaderQuery
        from netbluemind.backend.mail.api.SearchQueryHeaderQuery import __SearchQueryHeaderQuerySerDer__
        headerQueryValue = value.headerQuery
        instance["headerQuery"] = __SearchQueryHeaderQuerySerDer__().encode(headerQueryValue)
        maxResultsValue = value.maxResults
        instance["maxResults"] = serder.LONG.encode(maxResultsValue)
        offsetValue = value.offset
        instance["offset"] = serder.LONG.encode(offsetValue)
        from netbluemind.backend.mail.api.SearchQuerySearchScope import SearchQuerySearchScope
        from netbluemind.backend.mail.api.SearchQuerySearchScope import __SearchQuerySearchScopeSerDer__
        scopeValue = value.scope
        instance["scope"] = __SearchQuerySearchScopeSerDer__().encode(scopeValue)
        return instance

